Interstellar Extinction calculations
====================================

This module contains extinction law functions. See the documentation for
individual functions.

.. automodapi:: specutils.extinction
    :no-inheritance-diagram:
